# API Reference

Complete API documentation for all Nonconform modules and classes.

## Core Modules

### Estimation
::: nonconform.estimation
    options:
      show_root_heading: true
      heading_level: 3

### Strategy
::: nonconform.strategy
    options:
      show_root_heading: true
      heading_level: 3

### Utils
::: nonconform.utils
    options:
      show_root_heading: true
      heading_level: 3
